Module: QaServer
- Extended by:
- ActiveSupport::Autoload
- Defined in:
- app/models/qa_server/scenarios.rb,
lib/qa_server.rb,
lib/qa_server/engine.rb,
lib/qa_server/version.rb,
lib/qa_server/configuration.rb,
app/models/qa_server/term_scenario.rb,
app/models/qa_server/search_scenario.rb,
app/loggers/qa_server/scenario_logger.rb,
app/models/qa_server/authority_status.rb,
app/models/qa_server/authority_scenario.rb,
app/models/qa_server/performance_history.rb,
app/presenters/qa_server/fetch_presenter.rb,
app/services/qa_server/database_migrator.rb,
app/models/qa_server/scenario_run_history.rb,
app/models/qa_server/scenario_run_summary.rb,
app/controllers/qa_server/fetch_controller.rb,
app/controllers/qa_server/usage_controller.rb,
app/models/qa_server/scenario_run_registry.rb,
app/presenters/qa_server/navmenu_presenter.rb,
lib/generators/qa_server/install_generator.rb,
app/validators/qa_server/scenario_validator.rb,
app/controllers/qa_server/homepage_controller.rb,
app/models/qa_server/authority_status_failure.rb,
app/presenters/qa_server/check_status_presenter.rb,
app/services/qa_server/authority_lister_service.rb,
app/services/qa_server/authority_loader_service.rb,
app/services/qa_server/scenarios_loader_service.rb,
app/validators/qa_server/term_scenario_validator.rb,
app/controllers/qa_server/check_status_controller.rb,
app/presenters/qa_server/authority_list_presenter.rb,
app/presenters/qa_server/monitor_status_presenter.rb,
app/services/qa_server/authority_validator_service.rb,
app/validators/qa_server/search_scenario_validator.rb,
app/controllers/qa_server/authority_list_controller.rb,
app/controllers/qa_server/monitor_status_controller.rb,
app/services/qa_server/performance_graphing_service.rb,
app/services/qa_server/performance_calculator_service.rb,
app/services/qa_server/performance_graph_data_service.rb,
app/controllers/qa_server/authority_validation_controller.rb,
app/models/concerns/qa_server/performance_history_data_keys.rb
Overview
This module sets up the hash keys for performance data and allows them to be used across all classes setting and reading from the performance data hash.
Defined Under Namespace
Modules: MonitorStatus, PerformanceHistoryDataKeys Classes: AssetsGenerator, AuthorityListController, AuthorityListPresenter, AuthorityListerService, AuthorityLoaderService, AuthorityScenario, AuthorityStatus, AuthorityStatusFailure, AuthorityValidationController, AuthorityValidatorService, CheckStatusController, CheckStatusPresenter, ConfigGenerator, Configuration, DatabaseMigrator, Engine, FetchController, FetchPresenter, HomepageController, Install, ModelsGenerator, MonitorStatusController, MonitorStatusPresenter, NavmenuPresenter, PerformanceCalculatorService, PerformanceGraphDataService, PerformanceGraphingService, PerformanceHistory, ScenarioLogger, ScenarioRunHistory, ScenarioRunRegistry, ScenarioRunSummary, ScenarioValidator, Scenarios, ScenariosLoaderService, SearchScenario, SearchScenarioValidator, TermScenario, TermScenarioValidator, UsageController
Constant Summary collapse
- VERSION =
'3.0.0'
Class Method Summary collapse
-
.config {|Qa::Configuration| ... } ⇒ Qa::Configuration
Exposes the Questioning Authority configuration.
Class Method Details
.config {|Qa::Configuration| ... } ⇒ Qa::Configuration
Exposes the Questioning Authority configuration
17 18 19 20 21 22 23 |
# File 'lib/qa_server.rb', line 17 def self.config(&block) @config ||= QaServer::Configuration.new yield @config if block @config end |