Class: QaServer::AuthorityListPresenter
- Inherits:
-
Object
- Object
- QaServer::AuthorityListPresenter
- Defined in:
- app/presenters/qa_server/authority_list_presenter.rb
Instance Method Summary collapse
-
#initialize(urls_data:) ⇒ AuthorityListPresenter
constructor
A new instance of AuthorityListPresenter.
-
#urls_data ⇒ Array<Hash>
A list of status data for each scenario tested.
Constructor Details
#initialize(urls_data:) ⇒ AuthorityListPresenter
Returns a new instance of AuthorityListPresenter.
4 5 6 |
# File 'app/presenters/qa_server/authority_list_presenter.rb', line 4 def initialize(urls_data:) @urls_data = urls_data end |
Instance Method Details
#urls_data ⇒ Array<Hash>
Returns A list of status data for each scenario tested.
18 19 20 |
# File 'app/presenters/qa_server/authority_list_presenter.rb', line 18 def urls_data @urls_data end |