Class: QaServer::MonitorStatusController
- Inherits:
-
ApplicationController
- Object
- ApplicationController
- QaServer::MonitorStatusController
- Includes:
- AuthorityValidationBehavior
- Defined in:
- app/controllers/qa_server/monitor_status_controller.rb
Constant Summary
Constants included from AuthorityValidationBehavior
AuthorityValidationBehavior::ALL_VALIDATIONS, AuthorityValidationBehavior::DEFAULT_VALIDATION_TYPE, AuthorityValidationBehavior::VALIDATE_ACCURACY, AuthorityValidationBehavior::VALIDATE_CONNECTIONS, AuthorityValidationBehavior::VALIDATION_TYPE_PARAM
Instance Method Summary collapse
-
#index ⇒ Object
Sets up presenter with data to display in the UI.
Instance Method Details
#index ⇒ Object
Sets up presenter with data to display in the UI
21 22 23 24 25 26 27 28 29 30 |
# File 'app/controllers/qa_server/monitor_status_controller.rb', line 21 def index log_header latest_test_run @presenter = presenter_class.new(current_summary: latest_summary, current_failure_data: latest_failures, historical_summary_data: historical_data, performance_data: performance_table_data) update_performance_graphs render 'index', status: :internal_server_error if latest_summary..positive? end |