Class: QaServer::PerformanceGraphDataService
- Inherits:
-
Object
- Object
- QaServer::PerformanceGraphDataService
- Extended by:
- PerformanceHistoryDataKeys
- Defined in:
- app/services/qa_server/performance_graph_data_service.rb
Overview
rubocop:disable Metrics/ClassLength
Constant Summary
Constants included from PerformanceHistoryDataKeys
QaServer::PerformanceHistoryDataKeys::ALL_ACTIONS, QaServer::PerformanceHistoryDataKeys::ALL_AUTH, QaServer::PerformanceHistoryDataKeys::AVG_ACTN, QaServer::PerformanceHistoryDataKeys::AVG_FULL, QaServer::PerformanceHistoryDataKeys::AVG_GRPH, QaServer::PerformanceHistoryDataKeys::AVG_LOAD, QaServer::PerformanceHistoryDataKeys::AVG_NORM, QaServer::PerformanceHistoryDataKeys::AVG_RETR, QaServer::PerformanceHistoryDataKeys::BY_DAY, QaServer::PerformanceHistoryDataKeys::BY_HOUR, QaServer::PerformanceHistoryDataKeys::BY_MONTH, QaServer::PerformanceHistoryDataKeys::FETCH, QaServer::PerformanceHistoryDataKeys::FOR_DATATABLE, QaServer::PerformanceHistoryDataKeys::FOR_DAY, QaServer::PerformanceHistoryDataKeys::FOR_MONTH, QaServer::PerformanceHistoryDataKeys::FOR_YEAR, QaServer::PerformanceHistoryDataKeys::HIGH_ACTN, QaServer::PerformanceHistoryDataKeys::HIGH_FULL, QaServer::PerformanceHistoryDataKeys::HIGH_GRPH, QaServer::PerformanceHistoryDataKeys::HIGH_LOAD, QaServer::PerformanceHistoryDataKeys::HIGH_NORM, QaServer::PerformanceHistoryDataKeys::HIGH_RETR, QaServer::PerformanceHistoryDataKeys::LOW_ACTN, QaServer::PerformanceHistoryDataKeys::LOW_FULL, QaServer::PerformanceHistoryDataKeys::LOW_GRPH, QaServer::PerformanceHistoryDataKeys::LOW_LOAD, QaServer::PerformanceHistoryDataKeys::LOW_NORM, QaServer::PerformanceHistoryDataKeys::LOW_RETR, QaServer::PerformanceHistoryDataKeys::SEARCH, QaServer::PerformanceHistoryDataKeys::STATS
Class Method Summary collapse
-
.calculate_graph_data(force:) ⇒ Object
Performance data for a day, a month, a year, and all time for each authority.
Class Method Details
.calculate_graph_data(force:) ⇒ Object
Performance data for a day, a month, a year, and all time for each authority.
47 48 49 50 51 52 53 54 55 56 |
# File 'app/services/qa_server/performance_graph_data_service.rb', line 47 def calculate_graph_data(force:) QaServer.config.monitor_logger.info("(QaServer::PerformanceGraphDataService##{__method__}) - calculating performance graph data") QaServer.config.performance_cache.write_all data = {} auths = . calculate_all = force || cache_expired? data[ALL_AUTH] = (force: force, calculate_all: calculate_all) auths.each { |auth_name| data[auth_name] = (authority_name: auth_name, force: force, calculate_all: calculate_all) } data end |