Class: QaServer::MonitorStatusController
- Inherits:
-
AuthorityValidationController
- Object
- ApplicationController
- AuthorityValidationController
- QaServer::MonitorStatusController
- Defined in:
- app/controllers/qa_server/monitor_status_controller.rb
Constant Summary
Constants inherited from AuthorityValidationController
AuthorityValidationController::ALL_VALIDATIONS, AuthorityValidationController::DEFAULT_VALIDATION_TYPE, AuthorityValidationController::VALIDATE_ACCURACY, AuthorityValidationController::VALIDATE_CONNECTIONS, AuthorityValidationController::VALIDATION_TYPE_PARAM
Instance Attribute Summary
Attributes inherited from AuthorityValidationController
Instance Method Summary collapse
-
#index ⇒ Object
Sets up presenter with data to display in the UI.
Instance Method Details
#index ⇒ Object
Sets up presenter with data to display in the UI
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 |
# File 'app/controllers/qa_server/monitor_status_controller.rb', line 14 def index = if refresh? || expired_status? || .blank? validate() status_log.delete_passing = end @authority_count = .size # TODO: Include historical data too @presenter = presenter_class.new(authority_count: @authority_count, authority_status: @latest_authority_status, current_data: @status_data, historical_data: []) render 'index', :status => :internal_server_error if .failure_count.positive? end |